searchData={"items":[{"type":"module","title":"FlameEC2","doc":"A `FLAME.Backend` using [AWS EC2](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/concepts.html) machines.","ref":"FlameEC2.html"},{"type":"module","title":"How Does It Work? - FlameEC2","doc":"`FlameEC2` loads a release bundle that is stored in S3, and runs this release on a child node that it raises.\nThe release will always be run with the built in release start command, with the environment marking it as a FLAME child.\n\nTo facilitate shutdown of the node, `FlameEC2` runs the release under a systemd service, which is installed with a Post Stop hook\nthat will automatically run a shutdown command on the instance when the release is stopped. This, in combination with setting the\n`\"InstanceInitiatedShutdownBehavior\"` to `\"terminate\"`, guarantees that when the release is stopped, the instance will trigger its\nshutdown and termination behavior.","ref":"FlameEC2.html#module-how-does-it-work"},{"type":"module","title":"Usage - FlameEC2","doc":"To use, you must tell FLAME to use the `FlameEC2` backend by default.\nThis can be set via application configuration in your `config/runtime.exs` withing a `:prod` block:\n\n```elixir\nif config_env() == :prod do\n  config :flame, :backend, FlameEC2\n  ...\nend\n```\n\nYou must ensure that the IAM Role of whatever is running this backend has access to all of the necessary APIs.\nThe following is a minimal IAM Policy recommended to allow the backend to access all required APIs:\n\n```json\n{\n    \"Version\": \"2012-10-17\",\n    \"Statement\": [\n        {\n            \"Sid\": \"ec2RunInstances\",\n            \"Effect\": \"Allow\",\n            \"Action\": [\n                \"ec2:DescribeTags\",\n                \"ec2:CreateTags\",\n                \"ec2:DeleteTags\",\n                \"ec2:RunInstances\"\n            ],\n            \"Resource\": \"*\"\n        },\n        {\n            \"Sid\": \"ssmParameters\",\n            \"Effect\": \"Allow\",\n            \"Action\": [\n                \"ssm:GetParameters\"\n            ],\n            \"Resource\": \"*\"\n        },\n        {\n            \"Sid\": \"iamRolePassing\",\n            \"Effect\": \"Allow\",\n            \"Action\": [\n                \"iam:PassRole\"\n            ],\n            \"Resource\": [\n                \"arn:aws:iam::*:instance-profile/*\",\n                \"arn:aws:iam::*:role/*\"\n            ],\n            \"Condition\": {\n                \"StringEquals\": {\n                    \"iam:PassedToService\": \"ec2.amazonaws.com\"\n                }\n            }\n        },\n        {\n            \"Sid\": \"s3GetRelease\",\n            \"Effect\": \"Allow\",\n            \"Action\": [\n                \"s3:ListBucket\",\n                \"s3:GetObject\"\n            ],\n            \"Resource\": \"*\"\n        }\n    ]\n}\n```","ref":"FlameEC2.html#module-usage"},{"type":"module","title":"Configuration - FlameEC2","doc":"Configuration of the backend mirrors a subset of the\n[AWS EC2 LaunchInstance API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html) options,\nto allow us to raise a machine properly.\n\nAll of the configurations may be automatically set to the current instance's details by setting `auto_configure` to true:\n\n```elixir\nconfig :flame, FlameEC2, auto_configure: true\n...\n```\n\nIf you'd like to manually configure the details in your pool, you can read about the available configurations below.","ref":"FlameEC2.html#module-configuration"},{"type":"module","title":"Required Configurations - FlameEC2","doc":"* `:s3_bundle_url` - The S3 URL of your release bundle.\nThis value must be set in order to ensure that we can start the application properly on the child node.\nThe bundle is expected to either be a directory that will be synced locally onto the child node,\nor a `.tar.gz` file that will be copied to the node and decompressed.\n\n* `:app` - The name of your application. Defaults to `System.get_env(\"RELEASE_NAME\")`.\nIf this environment variable is not set for some reason, this value must be set in the configuration.\n\n* `:image_id` - The ID of the AMI to use. This is a required attribute if you are not using a launch template, and has no default.\n\n* `:launch_template_id` - The ID of the Launch Template to use. This is a required attribute if you are not using an image id, and has no default.\n\n* `:launch_template_version` - The version number of the launch template, or \"$Default\", or \"$Latest\". Defaults to \"$Default\".\n\n* `:subnet_id` - The subnet ID for the attached network interface. This is required in order to properly communicate with the instance.\n\n* `:security_group_id` - The security group ID for the attached network interface. This is required in order to properly communicate with the instance.","ref":"FlameEC2.html#module-required-configurations"},{"type":"module","title":"Optional Configurations - FlameEC2","doc":"* `:boot_timeout` - A timeout for booting a new node. Defaults to 120_000.\n\n* `:instance_type` - The instance type that should be used. Defaults to \"t3.nano\", which falls under the AWS free tier,\nhowever, you likely want to change this to something that's more appropriate for your pool's workload.\n\n* `:iam_instance_profile` - The ARN of the instance profile to assign to this machine.\nYou must ensure that this instance profile is set to a profile which can access whatever your FLAME nodes will need.\nWhen auto-configured, it will be set to the current machine's instance profile, however, in some cases this profile may\nbe too broad and you may want to create a role specific to the FLAME nodes.\n\n* `:key_name` - The name of the key pair to use for you to be able to connect to the instance.\nThis is not required, however, an instance that was created without a key pair will be inaccessible without another way to log in.\n\n* `:instance_metadata_url` - The EC2 instance metadata URL. This is used when auto-configuring the pool with the `auto_configure` configuration set to `true`.\nDefaults to \"http://169.254.169.254/latest/meta-data/\" (note the trailing slash), which is the internal EC2 metadata URL.\nThis can be adjusted for local testing, but likely does not need to be adjusted outside of this use case.\n\n* `:instance_metadata_token_url` - The EC2 instance metadata token URL. This is used when auto-configuring the pool with the `auto_configure` configuration set to `true`.\nDefaults to \"http://169.254.169.254/latest/api/token\", which is the internal EC2 metadata token URL.\nThis can be adjusted for local testing, but likely does not need to be adjusted outside of this use case.\n\n* `:ec2_service_endpoint` - The URL of the EC2. Defaults to \"https://ec2.amazonaws.com/\", which is the AWS EC2 endpoint.\nThis can be adjusted for local testing, but likely does not need to be adjusted outside of this use case.","ref":"FlameEC2.html#module-optional-configurations"},{"type":"module","title":"Environment Variables - FlameEC2","doc":"The FLAME EC2 machines *do not* inherit the environment variables of the parent.\nYou must explicit provide the environment that you would like to forward to the\nmachine. For example, if your FLAME's are starting your Ecto repos, you can copy\nthe env from the parent:\n\n```elixir\nconfig :flame, FlameEC2,\n  env: %{\n    \"DATABASE_URL\" => System.fetch_env!(\"DATABASE_URL\"),\n    \"POOL_SIZE\" => \"1\"\n  }\n```\n\nOr pass the env to each pool:\n\n```elixir\n{FLAME.Pool,\n  name: MyRunner,\n  backend: {FlameEC2, env: %{\"DATABASE_URL\" => System.fetch_env!(\"DATABASE_URL\")}}\n}\n```","ref":"FlameEC2.html#module-environment-variables"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Added new features","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Changed an existing functionality","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"- Deprecated a feature so that it can be removed in a later release","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"- Removed a feature","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a bugfix","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"- Patched a security vulnerability\n\n[Unreleased]: https://github.com/probably-not/flame-ec2/compare/v0.1.0...HEAD\n[0.1.0]: https://github.com/probably-not/flame-ec2/releases/tag/v0.1.0","ref":"changelog.html#security"},{"type":"extras","title":"README","doc":"# FlameEC2\n\nA FLAME backend for EC2 Machines.","ref":"readme.html"},{"type":"extras","title":"Why not K8S/ECS/Docker/etc? - README","doc":"I don't like complicating my deployments too much - while I have used K8S and ECS and Docker Compose and have spent years learning their ins and outs, I've recently started preferring simple bare-metal style deployments. Just give me a VPS with SSH access, plus something like Ansible, CodeDeploy (I am using AWS after all), or just simple rsync and a systemd service and I'm happy.\n\nWith that in mind - I want my FLAME cluster to shine (see what I did there?) without needing all this fluff as well.","ref":"readme.html#why-not-k8s-ecs-docker-etc"},{"type":"extras","title":"Installation - README","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `flame_ec2` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:flame_ec2, \"~> 0.0.1\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Contributing - README","doc":"Feel free to fork and make PRs! I'm definitely happy to have eyes on this and to get feedback so we can take care of edge cases.\n\nFor contributions, ensure that you run `git update-index --skip-worktree compose-env/ec2_mock_config.json`. The mock config gets reset\nand resynced in every `iex` session to ensure that the local compose environment is up to date for localized tests. This means that\nit is constantly changing, and therefore we should not track its changes. However, I do want to ensure that the file is distributed with\nthe repository, so that developers don't have to know to create it or have to do any setup before getting started.","ref":"readme.html#contributing"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}